@@ -32,10 +32,10 @@
 
 (defconst mudela-font-lock-keywords
   (let* ((keywords '(
-		     "accepts" "accidentals" "break" "bar" "cadenza" "clear" 
+		     "accepts" "accidentals" "break" "bar" "cadenza" 
 		     "clef" "cm" "consists" "contains" "duration" "absdynamic" 
-		     "in" "translator" "type" "lyric" "key" "maininput" "melodic"
-		     "musical_pitch" "meter" "midi" "mm" "multi" "header"
+		     "in" "translator" "type" "lyric" "key" "maininput" "notes"
+		     "musical_pitch" "meter" "midi" "mm" "header"
 		     "notenames" "octave" "output" "partial" "paper" "plet"
 		     "property" "pt" "shape" "relative" "include" "score"
 		     "script" "skip"  "table" "spandynamic" "symboltables"
